/// <reference types="core-js" />
/**
 * @license
 *
 * Copyright 2017 Anton Platonov <platosha@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Provider, Renderer, RootRenderer, RenderComponentType } from '@angular/core';
import { EventManager, AnimationDriver } from '@angular/platform-browser';
import { AnimationStyles, AnimationKeyframe, AnimationPlayer } from './private_import_angular_core';
export declare class PolymerRenderer implements Renderer {
    private _rootRenderer;
    private componentType;
    private _animationDriver;
    constructor(_rootRenderer: PolymerRootRenderer, componentType: RenderComponentType, _animationDriver: AnimationDriver);
    selectRootElement(selectorOrElement: string | Element): Element;
    createElement(parent: Element | DocumentFragment, name: string): Element;
    createViewRoot(hostElement: Element): Element | DocumentFragment;
    createTemplateAnchor(parent: Element | DocumentFragment): Element;
    createText(parent: Element | DocumentFragment, value: string): Node;
    projectNodes(parent: Element | DocumentFragment, nodes: Node[]): void;
    attachViewAfter(node: Node, viewRootNodes: Node[]): void;
    detachView(viewRootNodes: Node[]): void;
    destroyView(hostElement: Element | DocumentFragment, viewAllNodes: Node[]): void;
    listen(renderElement: any, name: string, callback: Function): Function;
    listenGlobal(target: string, name: string, callback: Function): Function;
    setElementProperty(renderElement: Element | DocumentFragment, propertyName: string, propertyValue: any): void;
    setElementAttribute(renderElement: Element | DocumentFragment, attributeName: string, attributeValue: string): void;
    setBindingDebugInfo(renderElement: Element, propertyName: string, propertyValue: string): void;
    setElementClass(renderElement: Element, className: string, isAdd: boolean): void;
    setElementStyle(renderElement: HTMLElement, styleName: string, styleValue: string): void;
    invokeElementMethod(renderElement: Element, methodName: string, args: any[]): void;
    setText(renderNode: Text, text: string): void;
    animate(element: any, startingStyles: AnimationStyles, keyframes: AnimationKeyframe[], duration: number, delay: number, easing: string, previousPlayers?: AnimationPlayer[]): AnimationPlayer;
}
export declare class PolymerRootRenderer implements RootRenderer {
    document: any;
    eventManager: EventManager;
    animationDriver: AnimationDriver;
    protected registeredComponents: Map<string, PolymerRenderer>;
    constructor(document: any, eventManager: EventManager, animationDriver: AnimationDriver);
    renderComponent(componentType: RenderComponentType): Renderer;
}
export declare const POLYMER_RENDER_PROVIDERS: Provider[];
export declare class PolymerModule {
}
