/**
 * @license
 *
 * Copyright 2017 Anton Platonov <platosha@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var core_1 = require('@angular/core');
var platform_browser_1 = require('@angular/platform-browser');
var private_import_angular_core_1 = require('./private_import_angular_core');
var Polymer = window.Polymer;
var PolymerRenderer = (function () {
    function PolymerRenderer(_rootRenderer, componentType, _animationDriver) {
        this._rootRenderer = _rootRenderer;
        this.componentType = componentType;
        this._animationDriver = _animationDriver;
    }
    PolymerRenderer.prototype.selectRootElement = function (selectorOrElement) {
        var el;
        if (typeof selectorOrElement === 'string') {
            el = Polymer.dom(this._rootRenderer.document).querySelector(selectorOrElement);
            if (!el) {
                throw new Error("Root element for selector \"" + selectorOrElement + "\" was not found");
            }
        }
        else {
            el = selectorOrElement;
        }
        Polymer.dom(el).textContent = '';
        return el;
    };
    PolymerRenderer.prototype.createElement = function (parent, name) {
        var el = document.createElement(name);
        if (parent) {
            Polymer.dom(parent).appendChild(el);
        }
        return el;
    };
    PolymerRenderer.prototype.createViewRoot = function (hostElement) {
        return hostElement;
    };
    PolymerRenderer.prototype.createTemplateAnchor = function (parent) {
        var anchor = document.createElement('template-anchor');
        anchor.setAttribute('hidden', 'hidden');
        if (parent) {
            Polymer.dom(parent).appendChild(anchor);
        }
        return anchor;
    };
    PolymerRenderer.prototype.createText = function (parent, value) {
        var node = document.createTextNode(value);
        if (parent) {
            Polymer.dom(parent).appendChild(node);
        }
        return node;
    };
    PolymerRenderer.prototype.projectNodes = function (parent, nodes) {
        if (!parent)
            return;
        var parentDomApi = Polymer.dom(parent);
        for (var i = 0; i < nodes.length; i++) {
            parentDomApi.appendChild(nodes[i]);
        }
    };
    PolymerRenderer.prototype.attachViewAfter = function (node, viewRootNodes) {
        var parent = Polymer.dom(node).parentNode;
        if (!parent || viewRootNodes.length === 0)
            return;
        var parentDomApi = Polymer.dom(parent);
        var nextSibling = Polymer.dom(node).nextSibling;
        if (nextSibling) {
            for (var i = 0; i < viewRootNodes.length; i++) {
                parentDomApi.insertBefore(viewRootNodes[i], nextSibling);
            }
        }
        else {
            for (var i = 0; i < viewRootNodes.length; i++) {
                parentDomApi.appendChild(viewRootNodes[i]);
            }
        }
    };
    PolymerRenderer.prototype.detachView = function (viewRootNodes) {
        for (var i = 0; i < viewRootNodes.length; i++) {
            var node = viewRootNodes[i];
            var parent_1 = Polymer.dom(node).parentNode;
            if (parent_1) {
                Polymer.dom(parent_1).removeChild(node);
            }
        }
    };
    PolymerRenderer.prototype.destroyView = function (hostElement, viewAllNodes) {
    };
    PolymerRenderer.prototype.listen = function (renderElement, name, callback) {
        return this._rootRenderer.eventManager.addEventListener(renderElement, name, decoratePreventDefault(callback));
    };
    PolymerRenderer.prototype.listenGlobal = function (target, name, callback) {
        return this._rootRenderer.eventManager.addGlobalEventListener(target, name, decoratePreventDefault(callback));
    };
    PolymerRenderer.prototype.setElementProperty = function (renderElement, propertyName, propertyValue) {
        renderElement[propertyName] = propertyValue;
    };
    PolymerRenderer.prototype.setElementAttribute = function (renderElement, attributeName, attributeValue) {
        if (attributeValue) {
            Polymer.dom(renderElement).setAttribute(attributeName, attributeValue);
        }
        else {
            Polymer.dom(renderElement).removeAttribute(attributeName);
        }
    };
    PolymerRenderer.prototype.setBindingDebugInfo = function (renderElement, propertyName, propertyValue) {
        this.setElementAttribute(renderElement, propertyName, propertyValue);
    };
    PolymerRenderer.prototype.setElementClass = function (renderElement, className, isAdd) {
        if (isAdd) {
            Polymer.dom(renderElement).classList.add(className);
        }
        else {
            Polymer.dom(renderElement).classList.remove(className);
        }
    };
    PolymerRenderer.prototype.setElementStyle = function (renderElement, styleName, styleValue) {
        if (styleValue) {
            renderElement.style.setProperty(styleName, styleValue);
        }
        else {
            renderElement.style.removeProperty(styleName);
        }
    };
    PolymerRenderer.prototype.invokeElementMethod = function (renderElement, methodName, args) {
        renderElement[methodName].apply(renderElement, args);
    };
    PolymerRenderer.prototype.setText = function (renderNode, text) {
        renderNode.nodeValue = text;
    };
    PolymerRenderer.prototype.animate = function (element, startingStyles, keyframes, duration, delay, easing, previousPlayers) {
        if (previousPlayers === void 0) { previousPlayers = []; }
        if (!element.domHost && this._rootRenderer.document.body.contains(element)) {
            return this._animationDriver.animate(element, startingStyles, keyframes, duration, delay, easing, previousPlayers);
        }
        return new private_import_angular_core_1.NoOpAnimationPlayer();
    };
    return PolymerRenderer;
}());
exports.PolymerRenderer = PolymerRenderer;
function decoratePreventDefault(handler) {
    return function (event) {
        var allowDefault = handler(event);
        if (allowDefault === false) {
            event.preventDefault();
            event.returnValue = false;
        }
    };
}
var PolymerRootRenderer = (function () {
    function PolymerRootRenderer(document, eventManager, animationDriver) {
        this.document = document;
        this.eventManager = eventManager;
        this.animationDriver = animationDriver;
        this.registeredComponents = new Map();
    }
    PolymerRootRenderer.prototype.renderComponent = function (componentType) {
        var renderer = this.registeredComponents.get(componentType.id);
        if (!renderer) {
            renderer = new PolymerRenderer(this, componentType, this.animationDriver);
            this.registeredComponents.set(componentType.id, renderer);
        }
        return renderer;
    };
    PolymerRootRenderer = __decorate([
        core_1.Injectable(),
        __param(0, core_1.Inject(platform_browser_1.DOCUMENT)), 
        __metadata('design:paramtypes', [Object, platform_browser_1.EventManager, platform_browser_1.AnimationDriver])
    ], PolymerRootRenderer);
    return PolymerRootRenderer;
}());
exports.PolymerRootRenderer = PolymerRootRenderer;
exports.POLYMER_RENDER_PROVIDERS = [
    PolymerRootRenderer,
    { provide: core_1.RootRenderer, useExisting: PolymerRootRenderer }
];
var PolymerModule = (function () {
    function PolymerModule() {
    }
    PolymerModule = __decorate([
        core_1.NgModule({
            exports: [platform_browser_1.BrowserModule],
            providers: [exports.POLYMER_RENDER_PROVIDERS]
        }), 
        __metadata('design:paramtypes', [])
    ], PolymerModule);
    return PolymerModule;
}());
exports.PolymerModule = PolymerModule;
//# sourceMappingURL=polymer.js.map